| MatrixFilterStates | R Documentation |
FilterStates subclass for matricesHandles filter states in a matrix.
FilterStates -> MatrixFilterStates
FilterStates$clear_filter_states()FilterStates$destroy()FilterStates$format()FilterStates$get_call()FilterStates$get_filter_state()FilterStates$print()FilterStates$remove_filter_state()FilterStates$set_filter_state()FilterStates$srv_active()FilterStates$srv_add()FilterStates$ui_active()FilterStates$ui_add()MatrixFilterStates$new()Initialize MatrixFilterStates object.
MatrixFilterStates$new( data, data_reactive = function(sid = "") NULL, dataname, datalabel = NULL )
data(matrix)
the R object which subset function is applied on.
data_reactive(function(sid))
should return a matrix object or NULL.
This object is needed for the FilterState counts being updated on a change in filters.
If function returns NULL then filtered counts are not shown.
Function has to have sid argument being a character.
dataname(character(1))
name of the data used in the subset expression.
Passed to the function argument attached to this FilterStates.
datalabel(character(1)) optional
text label. Should be a name of experiment.
MatrixFilterStates$clone()The objects of this class are cloneable with this method.
MatrixFilterStates$clone(deep = FALSE)
deepWhether to make a deep clone.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.