justify_json: Justify colons in 'JSON' string

View source: R/teal_slice.R

justify_jsonR Documentation

Justify colons in JSON string

Description

This function takes a JSON string as input, splits it into lines, and pads element names with spaces so that colons are justified between lines.

Usage

justify_json(json)

Arguments

json

(character(1)) a JSON string.

Value

A list of character strings, which can be collapsed into a JSON string.


teal.slice documentation built on June 4, 2026, 5:07 p.m.