| .drop_levels_keep_label | R Documentation |
Helper function to drop unused levels from a factor variable while preserving
the label attribute. The base R droplevels() function strips all attributes
except levels and class, which causes the loss of variable labels that are
commonly used in clinical trial datasets.
.drop_levels_keep_label(x)
x |
( |
The input factor with unused levels dropped and the label attribute preserved.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.